@@ -10,12 +10,13 @@ import ld_eventsource.actions
 from devcycle_python_sdk.api.config_client import ConfigAPIClient
 from devcycle_python_sdk.api.local_bucketing import LocalBucketing
 from devcycle_python_sdk.exceptions import (
-    CloudClientUnauthorizedError,
-    CloudClientError,
+    APIClientError,
+    APIClientUnauthorizedError,
 )
 from wsgiref.handlers import format_date_time
 from devcycle_python_sdk.options import DevCycleLocalOptions
 from devcycle_python_sdk.managers.sse_manager import SSEManager
+from devcycle_python_sdk.models.config_metadata import ConfigMetadata
 
 logger = logging.getLogger(__name__)
 
@@ -81,7 +82,10 @@ class EnvironmentConfigManager(threading.Thread):
             json_config = json.dumps(self._config)
             self._local_bucketing.store_config(json_config)
             if not self._options.disable_realtime_updates:
-                if self._sse_manager is None:
+                if (
+                    self._sse_manager is None
+                    or not self._sse_manager.client.is_connected()
+                ):
                     self._sse_manager = SSEManager(
                         self.sse_state,
                         self.sse_error,
@@ -100,14 +104,17 @@ class EnvironmentConfigManager(threading.Thread):
                     logger.warning(
                         f"DevCycle: Error received from on_client_initialized callback: {str(e)}"
                     )
-        except CloudClientError as e:
+        except APIClientError as e:
             logger.warning(f"DevCycle: Config fetch failed. Status: {str(e)}")
-        except CloudClientUnauthorizedError:
+        except APIClientUnauthorizedError:
             logger.error(
-                "DevCycle: Unauthorized to get config. Aborting config polling."
+                "DevCycle: Error initializing DevCycle: Invalid SDK key provided."
             )
             self._polling_enabled = False
 
+    def get_config_metadata(self) -> Optional[ConfigMetadata]:
+        return self._local_bucketing.get_config_metadata()
+
     def run(self):
         while self._polling_enabled:
             try:
@@ -124,9 +131,9 @@ class EnvironmentConfigManager(threading.Thread):
                 time.sleep(self._options.config_polling_interval_ms / 1000.0)
 
     def sse_message(self, message: ld_eventsource.actions.Event):
-        if self._sse_connected is False:
-            self._sse_connected = True
-            logger.info("DevCycle: Connected to SSE stream")
+        # Received a message from the SSE stream but our sse_connected is False, so we need to set it to True
+        if not self._sse_connected:
+            self.sse_state(None)
         logger.info(f"DevCycle: Received message: {message.data}")
         sse_message = json.loads(message.data)
         dvc_data = json.loads(sse_message.get("data"))
@@ -139,11 +146,13 @@ class EnvironmentConfigManager(threading.Thread):
             self._get_config(dvc_data["lastModified"] / 1000.0)
 
     def sse_error(self, error: ld_eventsource.actions.Fault):
+        self._sse_connected = False
         logger.debug(f"DevCycle: Received SSE error: {error}")
 
-    def sse_state(self, state: ld_eventsource.actions.Start):
-        self._sse_connected = True
-        logger.info("DevCycle: Connected to SSE stream")
+    def sse_state(self, state: Optional[ld_eventsource.actions.Start]):
+        if not self._sse_connected:
+            self._sse_connected = True
+            logger.info("DevCycle: Connected to SSE stream")
 
     def close(self):
         self._polling_enabled = False
