@@ -42,6 +42,8 @@ class SSEManager:
                     handle_error(event)
                 elif isinstance(event, ld_eventsource.actions.Event):
                     handle_message(event)
+                elif isinstance(event, ld_eventsource.actions.Comment):
+                    handle_state(None)
         except Exception as e:
             logger.debug(f"DevCycle: failed to read SSE message: {e}")
 
